/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigGui.h"

#include <kstandardshortcut.h>

#include <qlist.h>
#include <qkeysequence.h>
#include <qstring.h>


extern "C" {static PyObject *meth_KStandardShortcut_moveToTrash(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_moveToTrash(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::moveToTrash());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_moveToTrash, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_renameFile(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_renameFile(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::renameFile());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_renameFile, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_deleteFile(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_deleteFile(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::deleteFile());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_deleteFile, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_showMenubar(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_showMenubar(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::showMenubar());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_showMenubar, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_forwardWord(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_forwardWord(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::forwardWord());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_forwardWord, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_backwardWord(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_backwardWord(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::backwardWord());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_backwardWord, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_forward(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_forward(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::forward());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_forward, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_back(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_back(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::back());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_back, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_up(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_up(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::up());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_up, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_reload(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_reload(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::reload());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_reload, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_rotateDown(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_rotateDown(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::rotateDown());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_rotateDown, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_rotateUp(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_rotateUp(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::rotateUp());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_rotateUp, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_substringCompletion(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_substringCompletion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::substringCompletion());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_substringCompletion, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_nextCompletion(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_nextCompletion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::nextCompletion());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_nextCompletion, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_prevCompletion(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_prevCompletion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::prevCompletion());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_prevCompletion, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_completion(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_completion(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::completion());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_completion, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_help(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_help(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::help());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_help, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_fullScreen(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_fullScreen(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::fullScreen());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_fullScreen, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_tabPrev(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_tabPrev(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::tabPrev());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_tabPrev, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_tabNext(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_tabNext(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::tabNext());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_tabNext, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_addBookmark(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_addBookmark(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::addBookmark());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_addBookmark, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_gotoLine(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_gotoLine(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::gotoLine());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_gotoLine, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_next(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_next(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::next());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_next, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_prior(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_prior(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::prior());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_prior, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_endOfLine(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_endOfLine(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::endOfLine());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_endOfLine, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_beginningOfLine(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_beginningOfLine(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::beginningOfLine());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_beginningOfLine, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_end(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_end(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::end());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_end, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_begin(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_begin(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::begin());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_begin, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_home(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_home(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::home());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_home, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_zoomOut(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_zoomOut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::zoomOut());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_zoomOut, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_zoomIn(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_zoomIn(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::zoomIn());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_zoomIn, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_replace(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_replace(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::replace());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_replace, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_findPrev(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_findPrev(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::findPrev());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_findPrev, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_findNext(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_findNext(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::findNext());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_findNext, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_deleteWordForward(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_deleteWordForward(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::deleteWordForward());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_deleteWordForward, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_deleteWordBack(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_deleteWordBack(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::deleteWordBack());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_deleteWordBack, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_selectAll(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_selectAll(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::selectAll());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_selectAll, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_pasteSelection(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_pasteSelection(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::pasteSelection());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_pasteSelection, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_paste(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_paste(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::paste());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_paste, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_copy(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_copy(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::copy());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_copy, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_cut(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_cut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::cut());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_cut, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_redo(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_redo(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::redo());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_redo, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_undo(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_undo(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::undo());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_undo, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_quit(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_quit(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::quit());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_quit, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_print(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_print(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::print());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_print, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_save(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_save(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::save());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_save, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_close(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_close(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::close());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_close, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_openNew(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_openNew(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::openNew());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_openNew, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_open(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_open(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::open());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_open, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_saveShortcut(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_saveShortcut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KStandardShortcut::StandardShortcut a0;
        const QList< ::QKeySequence>* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "EJ1", sipType_KStandardShortcut_StandardShortcut, &a0, sipType_QList_0100QKeySequence,&a1, &a1State))
        {
             ::KStandardShortcut::saveShortcut(a0,*a1);
            sipReleaseType(const_cast<QList< ::QKeySequence> *>(a1),sipType_QList_0100QKeySequence,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_saveShortcut, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_hardcodedDefaultShortcut(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_hardcodedDefaultShortcut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KStandardShortcut::StandardShortcut a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_KStandardShortcut_StandardShortcut, &a0))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::hardcodedDefaultShortcut(a0));

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_hardcodedDefaultShortcut, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_find(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_find(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QKeySequence* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J1", sipType_QKeySequence, &a0, &a0State))
        {
             ::KStandardShortcut::StandardShortcut sipRes;

            sipRes =  ::KStandardShortcut::find(*a0);
            sipReleaseType(const_cast< ::QKeySequence *>(a0),sipType_QKeySequence,a0State);

            return sipConvertFromEnum(sipRes,sipType_KStandardShortcut_StandardShortcut);
        }
    }

    {
        const char* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "s", &a0))
        {
             ::KStandardShortcut::StandardShortcut sipRes;

            sipRes =  ::KStandardShortcut::find(a0);

            return sipConvertFromEnum(sipRes,sipType_KStandardShortcut_StandardShortcut);
        }
    }

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::find());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_find, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_whatsThis(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_whatsThis(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KStandardShortcut::StandardShortcut a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_KStandardShortcut_StandardShortcut, &a0))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::KStandardShortcut::whatsThis(a0));

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::whatsThis());

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_whatsThis, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_label(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_label(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KStandardShortcut::StandardShortcut a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_KStandardShortcut_StandardShortcut, &a0))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::KStandardShortcut::label(a0));

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_label, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_name(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_name(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KStandardShortcut::StandardShortcut a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_KStandardShortcut_StandardShortcut, &a0))
        {
             ::QString*sipRes;

            sipRes = new  ::QString( ::KStandardShortcut::name(a0));

            return sipConvertFromNewType(sipRes,sipType_QString,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_name, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KStandardShortcut_shortcut(PyObject *, PyObject *);}
static PyObject *meth_KStandardShortcut_shortcut(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
         ::KStandardShortcut::StandardShortcut a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_KStandardShortcut_StandardShortcut, &a0))
        {
            QList< ::QKeySequence>*sipRes;

            sipRes = new QList< ::QKeySequence>( ::KStandardShortcut::shortcut(a0));

            return sipConvertFromNewType(sipRes,sipType_QList_0100QKeySequence,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_shortcut, NULL);

    return NULL;
}


static PyMethodDef methods_KStandardShortcut[] = {
    {SIP_MLNAME_CAST(sipName_addBookmark), meth_KStandardShortcut_addBookmark, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_back), meth_KStandardShortcut_back, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_backwardWord), meth_KStandardShortcut_backwardWord, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_begin), meth_KStandardShortcut_begin, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_beginningOfLine), meth_KStandardShortcut_beginningOfLine, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_close), meth_KStandardShortcut_close, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_completion), meth_KStandardShortcut_completion, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_copy), meth_KStandardShortcut_copy, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_cut), meth_KStandardShortcut_cut, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_deleteFile), meth_KStandardShortcut_deleteFile, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_deleteWordBack), meth_KStandardShortcut_deleteWordBack, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_deleteWordForward), meth_KStandardShortcut_deleteWordForward, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_end), meth_KStandardShortcut_end, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_endOfLine), meth_KStandardShortcut_endOfLine, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_find), meth_KStandardShortcut_find, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_findNext), meth_KStandardShortcut_findNext, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_findPrev), meth_KStandardShortcut_findPrev, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_forward), meth_KStandardShortcut_forward, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_forwardWord), meth_KStandardShortcut_forwardWord, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_fullScreen), meth_KStandardShortcut_fullScreen, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_gotoLine), meth_KStandardShortcut_gotoLine, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_hardcodedDefaultShortcut), meth_KStandardShortcut_hardcodedDefaultShortcut, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_help), meth_KStandardShortcut_help, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_home), meth_KStandardShortcut_home, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_label), meth_KStandardShortcut_label, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_moveToTrash), meth_KStandardShortcut_moveToTrash, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_name), meth_KStandardShortcut_name, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_next), meth_KStandardShortcut_next, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_nextCompletion), meth_KStandardShortcut_nextCompletion, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_open), meth_KStandardShortcut_open, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_openNew), meth_KStandardShortcut_openNew, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_paste), meth_KStandardShortcut_paste, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_pasteSelection), meth_KStandardShortcut_pasteSelection, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_prevCompletion), meth_KStandardShortcut_prevCompletion, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_print), meth_KStandardShortcut_print, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_prior), meth_KStandardShortcut_prior, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_quit), meth_KStandardShortcut_quit, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_redo), meth_KStandardShortcut_redo, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_reload), meth_KStandardShortcut_reload, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_renameFile), meth_KStandardShortcut_renameFile, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_replace), meth_KStandardShortcut_replace, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_rotateDown), meth_KStandardShortcut_rotateDown, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_rotateUp), meth_KStandardShortcut_rotateUp, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_save), meth_KStandardShortcut_save, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_saveShortcut), meth_KStandardShortcut_saveShortcut, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_selectAll), meth_KStandardShortcut_selectAll, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_shortcut), meth_KStandardShortcut_shortcut, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_showMenubar), meth_KStandardShortcut_showMenubar, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_substringCompletion), meth_KStandardShortcut_substringCompletion, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_tabNext), meth_KStandardShortcut_tabNext, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_tabPrev), meth_KStandardShortcut_tabPrev, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_undo), meth_KStandardShortcut_undo, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_up), meth_KStandardShortcut_up, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_whatsThis), meth_KStandardShortcut_whatsThis, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_zoomIn), meth_KStandardShortcut_zoomIn, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_zoomOut), meth_KStandardShortcut_zoomOut, METH_VARARGS, NULL}
};

static sipEnumMemberDef enummembers_KStandardShortcut[] = {
    {sipName_AboutApp, static_cast<int>( ::KStandardShortcut::AboutApp), 6},
    {sipName_AboutKDE, static_cast<int>( ::KStandardShortcut::AboutKDE), 6},
    {sipName_AccelNone, static_cast<int>( ::KStandardShortcut::AccelNone), 6},
    {sipName_ActualSize, static_cast<int>( ::KStandardShortcut::ActualSize), 6},
    {sipName_AddBookmark, static_cast<int>( ::KStandardShortcut::AddBookmark), 6},
    {sipName_Back, static_cast<int>( ::KStandardShortcut::Back), 6},
    {sipName_BackwardWord, static_cast<int>( ::KStandardShortcut::BackwardWord), 6},
    {sipName_Begin, static_cast<int>( ::KStandardShortcut::Begin), 6},
    {sipName_BeginningOfLine, static_cast<int>( ::KStandardShortcut::BeginningOfLine), 6},
    {sipName_Clear, static_cast<int>( ::KStandardShortcut::Clear), 6},
    {sipName_Close, static_cast<int>( ::KStandardShortcut::Close), 6},
    {sipName_ConfigureNotifications, static_cast<int>( ::KStandardShortcut::ConfigureNotifications), 6},
    {sipName_ConfigureToolbars, static_cast<int>( ::KStandardShortcut::ConfigureToolbars), 6},
    {sipName_Copy, static_cast<int>( ::KStandardShortcut::Copy), 6},
    {sipName_Cut, static_cast<int>( ::KStandardShortcut::Cut), 6},
    {sipName_DeleteFile, static_cast<int>( ::KStandardShortcut::DeleteFile), 6},
    {sipName_DeleteWordBack, static_cast<int>( ::KStandardShortcut::DeleteWordBack), 6},
    {sipName_DeleteWordForward, static_cast<int>( ::KStandardShortcut::DeleteWordForward), 6},
    {sipName_Deselect, static_cast<int>( ::KStandardShortcut::Deselect), 6},
    {sipName_DocumentBack, static_cast<int>( ::KStandardShortcut::DocumentBack), 6},
    {sipName_DocumentForward, static_cast<int>( ::KStandardShortcut::DocumentForward), 6},
    {sipName_Donate, static_cast<int>( ::KStandardShortcut::Donate), 6},
    {sipName_EditBookmarks, static_cast<int>( ::KStandardShortcut::EditBookmarks), 6},
    {sipName_End, static_cast<int>( ::KStandardShortcut::End), 6},
    {sipName_EndOfLine, static_cast<int>( ::KStandardShortcut::EndOfLine), 6},
    {sipName_Find, static_cast<int>( ::KStandardShortcut::Find), 6},
    {sipName_FindNext, static_cast<int>( ::KStandardShortcut::FindNext), 6},
    {sipName_FindPrev, static_cast<int>( ::KStandardShortcut::FindPrev), 6},
    {sipName_FitToHeight, static_cast<int>( ::KStandardShortcut::FitToHeight), 6},
    {sipName_FitToPage, static_cast<int>( ::KStandardShortcut::FitToPage), 6},
    {sipName_FitToWidth, static_cast<int>( ::KStandardShortcut::FitToWidth), 6},
    {sipName_Forward, static_cast<int>( ::KStandardShortcut::Forward), 6},
    {sipName_ForwardWord, static_cast<int>( ::KStandardShortcut::ForwardWord), 6},
    {sipName_FullScreen, static_cast<int>( ::KStandardShortcut::FullScreen), 6},
    {sipName_Goto, static_cast<int>( ::KStandardShortcut::Goto), 6},
    {sipName_GotoLine, static_cast<int>( ::KStandardShortcut::GotoLine), 6},
    {sipName_GotoPage, static_cast<int>( ::KStandardShortcut::GotoPage), 6},
    {sipName_Help, static_cast<int>( ::KStandardShortcut::Help), 6},
    {sipName_Home, static_cast<int>( ::KStandardShortcut::Home), 6},
    {sipName_KeyBindings, static_cast<int>( ::KStandardShortcut::KeyBindings), 6},
    {sipName_Mail, static_cast<int>( ::KStandardShortcut::Mail), 6},
    {sipName_MoveToTrash, static_cast<int>( ::KStandardShortcut::MoveToTrash), 6},
    {sipName_New, static_cast<int>( ::KStandardShortcut::New), 6},
    {sipName_Next, static_cast<int>( ::KStandardShortcut::Next), 6},
    {sipName_NextCompletion, static_cast<int>( ::KStandardShortcut::NextCompletion), 6},
    {sipName_Open, static_cast<int>( ::KStandardShortcut::Open), 6},
    {sipName_OpenRecent, static_cast<int>( ::KStandardShortcut::OpenRecent), 6},
    {sipName_Paste, static_cast<int>( ::KStandardShortcut::Paste), 6},
    {sipName_PasteSelection, static_cast<int>( ::KStandardShortcut::PasteSelection), 6},
    {sipName_Preferences, static_cast<int>( ::KStandardShortcut::Preferences), 6},
    {sipName_PrevCompletion, static_cast<int>( ::KStandardShortcut::PrevCompletion), 6},
    {sipName_Print, static_cast<int>( ::KStandardShortcut::Print), 6},
    {sipName_PrintPreview, static_cast<int>( ::KStandardShortcut::PrintPreview), 6},
    {sipName_Prior, static_cast<int>( ::KStandardShortcut::Prior), 6},
    {sipName_Quit, static_cast<int>( ::KStandardShortcut::Quit), 6},
    {sipName_Redo, static_cast<int>( ::KStandardShortcut::Redo), 6},
    {sipName_Reload, static_cast<int>( ::KStandardShortcut::Reload), 6},
    {sipName_RenameFile, static_cast<int>( ::KStandardShortcut::RenameFile), 6},
    {sipName_Replace, static_cast<int>( ::KStandardShortcut::Replace), 6},
    {sipName_ReportBug, static_cast<int>( ::KStandardShortcut::ReportBug), 6},
    {sipName_Revert, static_cast<int>( ::KStandardShortcut::Revert), 6},
    {sipName_RotateDown, static_cast<int>( ::KStandardShortcut::RotateDown), 6},
    {sipName_RotateUp, static_cast<int>( ::KStandardShortcut::RotateUp), 6},
    {sipName_Save, static_cast<int>( ::KStandardShortcut::Save), 6},
    {sipName_SaveAs, static_cast<int>( ::KStandardShortcut::SaveAs), 6},
    {sipName_SaveOptions, static_cast<int>( ::KStandardShortcut::SaveOptions), 6},
    {sipName_SelectAll, static_cast<int>( ::KStandardShortcut::SelectAll), 6},
    {sipName_ShowMenubar, static_cast<int>( ::KStandardShortcut::ShowMenubar), 6},
    {sipName_ShowStatusbar, static_cast<int>( ::KStandardShortcut::ShowStatusbar), 6},
    {sipName_ShowToolbar, static_cast<int>( ::KStandardShortcut::ShowToolbar), 6},
    {sipName_Spelling, static_cast<int>( ::KStandardShortcut::Spelling), 6},
    {sipName_StandardShortcutCount, static_cast<int>( ::KStandardShortcut::StandardShortcutCount), 6},
    {sipName_SubstringCompletion, static_cast<int>( ::KStandardShortcut::SubstringCompletion), 6},
    {sipName_SwitchApplicationLanguage, static_cast<int>( ::KStandardShortcut::SwitchApplicationLanguage), 6},
    {sipName_TabNext, static_cast<int>( ::KStandardShortcut::TabNext), 6},
    {sipName_TabPrev, static_cast<int>( ::KStandardShortcut::TabPrev), 6},
    {sipName_TextCompletion, static_cast<int>( ::KStandardShortcut::TextCompletion), 6},
    {sipName_TipofDay, static_cast<int>( ::KStandardShortcut::TipofDay), 6},
    {sipName_Undo, static_cast<int>( ::KStandardShortcut::Undo), 6},
    {sipName_Up, static_cast<int>( ::KStandardShortcut::Up), 6},
    {sipName_WhatsThis, static_cast<int>( ::KStandardShortcut::WhatsThis), 6},
    {sipName_Zoom, static_cast<int>( ::KStandardShortcut::Zoom), 6},
    {sipName_ZoomIn, static_cast<int>( ::KStandardShortcut::ZoomIn), 6},
    {sipName_ZoomOut, static_cast<int>( ::KStandardShortcut::ZoomOut), 6},
};


static pyqt5ClassPluginDef plugin_KStandardShortcut = {
    0,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigGui_KStandardShortcut = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_NAMESPACE,
        sipNameNr_KStandardShortcut,
        {0},
        &plugin_KStandardShortcut
    },
    {
        sipNameNr_KStandardShortcut,
        {0, 0, 1},
        56, methods_KStandardShortcut,
        84, enummembers_KStandardShortcut,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    0,
    0,
    0,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
};
